@@ -1,11 +1,17 @@
 package POD2::RU;
+
+# ABSTRACT: Translate Perl documantation to Russian language
 use utf8;
 use strict;
 use warnings;
 use base 'Exporter';
 use base 'POD2::Base';
+use IO::Interactive qw(is_interactive);
+use Encode::Locale qw(decode_argv);
 
-our $VERSION = '5.18.0.1.14';
+
+use 5.008_005;
+our $VERSION = '5.18.0.1.16';
 
 our @EXPORT = qw(print_pod print_pods);
 
@@ -81,8 +87,7 @@ sub print_pods {
 }
 
 sub prepare_encoding_console {
-    use Encode::Locale qw(decode_argv);
-    if (-t) {
+    if (is_interactive()) {
         binmode( STDIN,  ":encoding(console_in)" );
         binmode( STDOUT, ":encoding(console_out)" );
         binmode( STDERR, ":encoding(console_out)" );
@@ -91,16 +96,17 @@ sub prepare_encoding_console {
 }
 
 1;
-
 __END__
 
-=encoding utf8
+=encoding utf-8
 
-=head1 ИМЯ
+=head1 NAME
 
 POD2::RU - Perl Документация по-русски
 
-=head1 СИНТАКСИС
+=head1 SYNOPSIS
+
+  use POD2::RU;
 
   $ perldoc POD2::RU::<название_pod>
 
@@ -116,8 +122,9 @@ POD2::RU - Perl Документация по-русски
   $pod2->print_pods();
   $pod2->print_pod('perlfunc');
                                                                                           
+=head1 DESCRIPTION
 
-=head1 ОПИСАНИЕ
+POD2::RU is
 
 Этот модуль содержит перевод Perl-документации на русский. Домашняя страница проекта ─ L<https://github.com/mishin/perldoc-ru>. 
 
@@ -177,6 +184,10 @@ C<< perldoc -f function >> использует возвращаемое зна
 
 =back
 
+=head1 AUTHOR
+
+Nikolay Mishin E<lt>mi@ya.ruE<gt>
+
 =head1 АВТОРЫ
 
 =over
@@ -193,60 +204,25 @@ C<< perldoc -f function >> использует возвращаемое зна
 
 =back
 
-=head1 ПРОЕКТ
+=head1 COPYRIGHT
 
-Домашняя страница L<https://github.com/mishin/perldoc-ru>.
+Copyright 2015- Nikolay Mishin
 
+=head1 LICENSE
 
-=head1 СМОТРИТЕ ТАКЖЕ
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 SEE ALSO
 
 L<POD2::ES>, L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>.
 
-
-=head1 ПОЖЕРТВОВАНИЕ
+=head1 DONATIONS
 
 Проект перевода документации Perl требует постоянных усилий, что доступно только для сильных духов и альтруистов.
 Авторы не просят, но ни не отвергают помощь в виде денег, книг, сыра и продуктов из свинины (можно хамон;) ), или даже поездки в Полинезию для снижения утомления и сохранения боевого духа команды. Мы приглашаем всех.
 
-
-
-=head1 ОШИБКИ
-
-Информацию об ошибках и пожелания можно оставить на странице
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD2-RU> или
-отправить на e-mail C<bug-pod2-ru at rt.cpan.org>, C<mi at ya.ru>.
-
-=head1 ПОДДЕРЖКА
-
-Для просмотра документации в этом модуле, используйте команду C<perldoc>.
-
-    perldoc POD2::RU
-
-
-Вы также можете найти информацию о:
-
-=over 4
-
-=item * RT: системы отслеживания ощибок для CPAN
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POD2-RU>
-
-=item * AnnoCPAN: аннотированная документация CPAN
-
-L<http://annocpan.org/dist/POD2-RU>
-
-=item * Рейтинги CPAN
-
-L<http://cpanratings.perl.org/d/POD2-RU>
-
-=item * Поиск CPAN модулей
-
-L<http://search.cpan.org/dist/POD2-RU/>
-
-=back
-
-
-=head1 БЛАГОДАРНОСТЬ
+=head1 THANKS 
 
 Авторы хотели бы выразить свою благодарность команде разработчиков OmegaT, инструмента, который используется для перевода.
 
@@ -265,14 +241,4 @@ L<http://sourceforge.jp/cvs/view/perldocjp/docs/modules/>
 
 They are using a traditional mailing list and sourceforge's bug tracking system. In my opinion, github would be a much better way to manage those things at the moment. github was not exist when they started the project.
 
-
-=head1 ЛИЦЕНЗИИ И АВТОРСКИЕ ПРАВА
-
-Copyright (C) 2011-2013 Команда Perl по-русски, Moscow-pm.
-
-Данная программа является свободным программным обеспечением, вы можете распространять и изменять его в соответствии с условиями общественной лицензии GNU GPL, опубликованной Фондом свободного программного обеспечения, или Artistic License.
-
-См. L<http://dev.perl.org/licenses> для более подробной информации.
-
-
 =cut
